@@ -1,5 +1,6 @@
 require("testthat")
 
+# input matrix as strings
 test_that("Tests of pairwise comparison matrix", {
   comparisonMatrixValues = c("1","9","5",
                        "1/9","1","1/3",
@@ -9,15 +10,25 @@ test_that("Tests of pairwise comparison matrix", {
   expect_is(matrix, "PairwiseComparisonMatrix")
 })
 
-# since version 0.6.9 it is possible to construct the pairwise comparison matrix event from numerical matrix
-# test_that("Tests of pairwise comparison matrix - failed (matrix is numerical)", {
-#   comparisonMatrixValues = c(1,9,5,
-#                              1/9,1,1/3,
-#                              1/5,3,1)
-#   comparisonMatrix = matrix(comparisonMatrixValues, nrow = 3, ncol = 3, byrow = TRUE)
-#   expect_error(pairwiseComparisonMatrix(comparisonMatrix),
-#                "The pairwise comparison matrix needs to be of type character but is double.")
-# })
+# input matrix as values with lower triangle empty
+test_that("Tests of pairwise comparison matrix", {
+  comparisonMatrixValues = c(1,9,5,
+                             NA,1,1/3,
+                             NA,NA,1)
+  comparisonMatrix = matrix(comparisonMatrixValues, nrow = 3, ncol = 3, byrow = TRUE)
+  matrix = pairwiseComparisonMatrix(comparisonMatrix)
+  expect_is(matrix, "PairwiseComparisonMatrix")
+})
+
+# input matrix as values with upper triangle as zeroes
+test_that("Tests of pairwise comparison matrix", {
+  comparisonMatrixValues = c(1,0,0,
+                             1/9,1,0,
+                             1/5,3,1)
+  comparisonMatrix = matrix(comparisonMatrixValues, nrow = 3, ncol = 3, byrow = TRUE)
+  matrix = pairwiseComparisonMatrix(comparisonMatrix)
+  expect_is(matrix, "PairwiseComparisonMatrix")
+})
 
 test_that("Tests of pairwise comparison matrix - failed (matrix does not have ones on diagonal)", {
   comparisonMatrixValues = c("1","9","5",
